"""
OrKa Vintage Theme - Classic Green Phosphor CRT Aesthetic
Register this theme with Textual for user selection.
"""
from textual.theme import Theme

# Define the vintage CRT theme
VINTAGE = Theme(
    name="orka-vintage",
    primary="#00ff00",
    secondary="#00ff00", 
    warning="#ffaa00",
    error="#ff3333",
    success="#00ff00",
    accent="#ccffcc",
    foreground="#aaffaa",
    background="#000000",
    surface="#001100",
    panel="#002200",
)
